summaryrefslogtreecommitdiffstats
path: root/libk9copy/progress.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libk9copy/progress.cpp')
-rw-r--r--libk9copy/progress.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/libk9copy/progress.cpp b/libk9copy/progress.cpp
index 24f5c68..e71faf9 100644
--- a/libk9copy/progress.cpp
+++ b/libk9copy/progress.cpp
@@ -20,11 +20,11 @@
#include "kprogress.h"
/*
* Constructs a Progress as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-Progress::Progress( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+Progress::Progress( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "Progress" );
@@ -20,11 +20,11 @@
#include "kprogress.h"
/*
- * Constructs a Progress as a child of 'tqparent', with the
+ * Constructs a Progress as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/